@@ -29,9 +29,15 @@ macro_rules! equivalent {
 
         // Through a string equivalent
         println!("to_string(literal)");
-        assert_eq!(t!(toml_edit::easy::to_string(&literal)), toml.to_string());
+        assert_eq!(
+            t!(toml_edit::easy::to_string_pretty(&literal)),
+            toml.to_string()
+        );
         println!("to_string(toml)");
-        assert_eq!(t!(toml_edit::easy::to_string(&toml)), toml.to_string());
+        assert_eq!(
+            t!(toml_edit::easy::to_string_pretty(&toml)),
+            toml.to_string()
+        );
         println!("literal, from_str(toml)");
         assert_eq!(literal, t!(toml_edit::easy::from_str(&toml.to_string())));
         println!("toml, from_str(toml)");
@@ -211,8 +217,8 @@ fn type_errors() {
         Table(map! {
             bar: Value::String("a".to_string())
         }),
-        "invalid type: string \"a\", expected isize",
-        "invalid type: string \"a\", expected isize"
+        "invalid type: string \"a\", expected isize for key `bar`",
+        "invalid type: string \"a\", expected isize for key `bar`"
     }
 
     #[derive(Deserialize)]
@@ -228,8 +234,8 @@ fn type_errors() {
                 bar: Value::String("a".to_string())
             })
         }),
-        "invalid type: string \"a\", expected isize",
-        "invalid type: string \"a\", expected isize"
+        "invalid type: string \"a\", expected isize for key `foo.bar`",
+        "invalid type: string \"a\", expected isize for key `foo.bar`"
     }
 }
 
@@ -346,7 +352,7 @@ fn extra_keys() {
 
     let toml = Table(map! { a: Integer(2), b: Integer(2) });
     assert!(toml.clone().try_into::<Foo>().is_ok());
-    assert!(toml::from_str::<Foo>(&toml.to_string()).is_ok());
+    assert!(toml_edit::de::from_str::<Foo>(&toml.to_string()).is_ok());
 }
 
 #[test]
@@ -402,8 +408,8 @@ struct CanBeEmpty {
 
 #[test]
 fn table_structs_empty() {
-    let text = "[bar]\n\n[baz]\n\n[bazv]\na = \"foo\"\n\n[foo]\n";
-    let value: BTreeMap<String, CanBeEmpty> = toml::from_str(text).unwrap();
+    let text = "bar = {}\nbaz = {}\nbazv = { a = \"foo\" }\nfoo = {}\n";
+    let value: BTreeMap<String, CanBeEmpty> = toml_edit::de::from_str(text).unwrap();
     let mut expected: BTreeMap<String, CanBeEmpty> = BTreeMap::new();
     expected.insert("bar".to_string(), CanBeEmpty::default());
     expected.insert("baz".to_string(), CanBeEmpty::default());
@@ -416,7 +422,7 @@ fn table_structs_empty() {
     );
     expected.insert("foo".to_string(), CanBeEmpty::default());
     assert_eq!(value, expected);
-    assert_eq!(toml::to_string(&value).unwrap(), text);
+    assert_eq!(toml_edit::ser::to_string(&value).unwrap(), text);
 }
 
 #[test]
@@ -460,7 +466,7 @@ fn homogeneous_tuple() {
 fn json_interoperability() {
     #[derive(Serialize, Deserialize)]
     struct Foo {
-        any: toml::Value,
+        any: toml_edit::easy::Value,
     }
 
     let _foo: Foo = serde_json::from_str(
@@ -470,3 +476,65 @@ fn json_interoperability() {
     )
     .unwrap();
 }
+
+#[test]
+fn error_includes_key() {
+    #[derive(Debug, Serialize, Deserialize)]
+    struct Package {
+        name: String,
+        version: String,
+        authors: Vec<String>,
+        profile: Profile,
+    }
+
+    #[derive(Debug, Serialize, Deserialize)]
+    struct Profile {
+        dev: Dev,
+    }
+
+    #[derive(Debug, Serialize, Deserialize)]
+    struct Dev {
+        debug: U32OrBool,
+    }
+
+    #[derive(Clone, Debug, Deserialize, Serialize, Eq, PartialEq)]
+    #[serde(untagged, expecting = "expected a boolean or an integer")]
+    pub enum U32OrBool {
+        U32(u32),
+        Bool(bool),
+    }
+
+    let res: Result<Package, _> = toml_edit::de::from_str(
+        r#"
+[package]
+name = "foo"
+version = "0.0.0"
+authors = []
+
+[profile.dev]
+debug = 'a'
+"#,
+    );
+    let err = res.unwrap_err();
+    assert_eq!(
+        err.to_string(),
+        "expected a boolean or an integer for key `profile.dev.debug`"
+    );
+
+    let res: Result<Package, _> = toml_edit::de::from_str(
+        r#"
+[package]
+name = "foo"
+version = "0.0.0"
+authors = []
+
+[profile]
+dev = { debug = 'a' }
+"#,
+    );
+    let err = res.unwrap_err();
+    assert_eq!(
+        err.to_string(),
+        "expected a boolean or an integer for key `profile.dev.debug`"
+    );
+}
